@@ -1,34 +1,9 @@
 import subprocess
 
 VERSION = subprocess.getoutput("pip freeze | grep mailshell").split("==")[1]
-DESCRIPTION = "\nsend and check emails faster from the terminal"
+DESCRIPTION = "send and check emails faster from the terminal"
 COPYRIGHT = "Copyright (c) 2022 Malki Abderrahman"
-EPILOG = "Thanks for using Mailshell\nproject home page on https://github.com/malkiAbdoo/mailshell"
-SHELL_COMMANDS = """
-commands:
-	logo  --> prints the Email logo.
-	login  --> log in to your gmail using email address and the app password.
-	logout  --> log out from your gmail.
-	cred  --> print your current email address and app password.
-	new  --> create new email message.
-	subject  --> set a new subject to the message.
-	from --> set a new sender name.
-	edit  --> edit your current message.
-	html  --> add html message.
-	content  --> see the current message content with the included files.
-	get [FILENAME]  --> add a text from .txt file to you current message.
-	add [FILENAME]  --> add a file or image to your message.
-	rm [FILENAME]  --> remove a file or image from your message.
-	to  --> set your contact that you will send to.
-	send  --> send the current message.
-	check  --> check your emails with a specified mailbox and search command.
-	sch  --> print the search commands that you need for checking emails.
-	ls  --> print the list of files and folders in the current folder.
-	pwd  --> print working directory.
-	clear  --> clear the terminal.
-	vertion --> see your current version.
-	exit  --> exit from Mailshell.
-"""
+EPILOG = "project home page on https://github.com/malkiAbdoo/mailshell"
 IMAP_CRITERIAS = r"""
 Search commands:
 
@@ -114,12 +89,3 @@ Messages that do not have the specified keyword set.
 Messages that do not have the \Seen flag set.
 """
 
-def shell_commands():
-	print('Mailshell ' + VERSION, COPYRIGHT,
-		  "Distributed under the MIT License.",
-		  DESCRIPTION, sep='\n')
-	print(SHELL_COMMANDS, EPILOG, sep='\n')
-
-def get_version():
-	print('Mailshell ' + VERSION, COPYRIGHT, sep='\n')
-
